.. _apihowto:

#######################################
API howto
#######################################

The following shows a series of python scripts which shows some uses of masai

.. note:: still very incomplete, sorry

reading and processing
=======================

.. toctree::
    
	proc1D_1
	proc1D_2		
	
